unit ReposApp;
{ Saves & Restores a form's position to and from an ini file
  Gives full control of inifile name, section heading, and names of variables,
  as well as default values. The inifile will be created if it doesn't exist
  two Methods: 1) LoadAppPosition - Load values from ini and applies to form
               2) SaveAppPosition - Save Current Values to infile
  LoadAppPosition should be placed in formshow, not formcreate and
  SaveAppPosition can be placed anywhere, onclose works fine
  Freeware Use & Abuse
  Author: Edward de la Rey
          edwardr@mailbox.ru.ac.za
          USE AT OWN RISK
  For Delphi 1,2,3 Will Automatically pickup the correct DCR File,
  D16 is for Delphi1, D32 for Delphi 2&3, Don't rename them.}
 
interface
{$IFDEF WIN32}
uses
  Windows, Messages, SysUtils, Classes, Controls, Forms,Registry;
{$ELSE}
uses
  SysUtils, WinTypes, WinProcs, Messages, Classes,  Controls,
  Forms,IniFiles;
{$ENDIF}


Const
  DefTop = 100;DefLeft = 100;DefHeight = 300;DefWidth = 300;
  DefLeftName = 'Left'; DefTopName ='Top'; DefHeightName = 'Height';DefWidthName= 'Width';
  DefIniFileName = 'MyApp';DefSectionName = 'Dimensions';DefWindowStateName='MyWindowState';

type
  TRePosApp = class(TComponent)
  private
    { Private declarations }
    GetTop:Word;
    GetLeft:Word;
    GetHeight:Word;
    GetWidth:Word;
    GetLeftName:String;
    GetTopName:String;
    GetHeightName:String;
    GetWidthName:String;
    GetSectionName:String;
    GetIniFileName:String;
    GetWindowStateName:String;
    Procedure SetTop(Value:Word);
    Procedure SetLeft(Value:Word);
    Procedure SetHeight(Value:Word);
    Procedure SetWidth(Value:Word);
    Procedure SetLeftName (Value:String);
    Procedure SetTopName (Value:String);
    Procedure SetHeightName (Value:String);
    Procedure SetWidthName (Value:String);
    Procedure SetWindowStateName(Value:String);
    Procedure SetIniFileName(Value:String);
    Procedure SetSectionName(Value:String);
  protected
    { Protected declarations }
  public
    { Public declarations }
  published
    { Published declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    Procedure LoadAppPosition; {Get the app position from inifile, use defaults if necessary}
    Procedure SaveAppPosition; {Save the app position to inifile}
    property Top:Word Read GetTop Write SetTop;
    property Left:Word Read GetLeft Write SetLeft;
    property Height:Word Read GetHeight Write SetHeight;
    property Width:Word Read GetWidth Write SetWidth;
    Property LeftName:String Read GetLeftName Write SetLeftName;
    Property TopName:String Read GetTopName Write SetTopName;
    Property HeightName:String Read GetHeightName Write SetHeightName;
    Property WidthName:String Read GetWidthName Write SetWidthName;
    Property InifileName:String Read GetIniFileName Write SetIniFileName;
    Property SectionName:String Read GetSectionName Write SetSectionName;
    Property WindowStateName:String Read GetWindowStateName Write SetWindowStateName;
  end;

procedure Register;

implementation

{$IFDEF WIN32}
{$R *.D32}
{$ELSE}
{$R *.D16}
{$ENDIF}

constructor TRePosApp.Create(AOwner: TComponent);
begin
   INHERITED CREATE(Aowner);
   GetLeftName:=DefLeftName;
   GetTopName:=DefTopName;
   GetHeightName:=DefHeightName;
   GetWidthName:=DefWidthName;
   GetSectionName:=DefSectionName;
   GetIniFileName:=DefIniFileName;
   GetWindowStateName:=DefWindowStateName;
   GetTop:=DefTop;
   GetLeft:=DefLeft;
   GetHeight:=DefHeight;
   GetWidth:=DefWidth;
End;

destructor TRePosApp.Destroy;
begin
  inherited Destroy;
end;

Procedure TRePosApp.LoadAppPosition;
Var
{$IFDEF WIN32}
IniFile:TRegInifile;
{$ELSE}
IniFile:TInifile;
{$ENDIF}
TheTop,TheLeft,TheHeight,TheWidth:Integer;
begin
 {$IFDEF WIN32}
  INIFile := TRegINIFile.Create(GetIniFileName+'.INI');
 {$ELSE}
 INIFile := TINIFile.Create(GetIniFileName+'.INI');
 {$ENDIF}

 TheTop := inifile.readinteger(GetSectionName,GetTopName,GetTop);
 TheLeft := inifile.readinteger(GetSectionName,GetLeftName,GetLeft);
 TheHeight := inifile.readinteger(GetSectionName,GetHeightName,GetHeight);
 TheWidth := inifile.readinteger(GetSectionName,GetWidthName,GetWidth);

     Tform(Owner).width:=TheWidth;
     Tform(Owner).Height:=TheHeight;
     Tform(Owner).Left:=TheLeft;
     Tform(Owner).Top:=TheTop;

     if (comparetext(inifile.readstring(GetSectionName,GetWindowStateName,'False'),'True') = 0) then
     begin
     Tform(Owner).windowstate:=wsmaximized;
      end
     else
     begin
     Tform(Owner).windowstate :=wsNormal;
     end;
end;

Procedure TRePosApp.SaveAppPosition;
Var
{$IFDEF WIN32}
IniFile:TRegInifile;
{$ELSE}
IniFile:TInifile;
{$ENDIF}
begin
 {$IFDEF WIN32}
  INIFile := TRegINIFile.Create(GetIniFileName+'.INI');
 {$ELSE}
 INIFile := TINIFile.Create(GetIniFileName+'.INI');
 {$ENDIF}

     if Tform(Owner).windowstate = wsmaximized then
     INIFile.WriteString(GetSectionName,GetWindowStateName,'True')
     else begin
     INIFile.WriteString(GetSectionName,GetWindowStateName,'False');
     INIFile.WriteInteger(GetSectionName,GetTopName,Tform(Owner).Top);
     INIFile.WriteInteger(GetSectionName,GetLeftName,Tform(Owner).left);
     INIFile.WriteInteger(GetSectionName,GetWidthName,Tform(Owner).Width);
     INIFile.WriteInteger(GetSectionName,GetHeightName,Tform(Owner).Height);
     end;
end;

procedure TReposApp.SetWindowStateName (Value:String);
begin
     GetWindowStateName:=Value;
end;

procedure TReposApp.SetSectionName (Value:String);
begin
     GetSectionName:=Value;
end;

procedure TReposApp.SetIniFileName (Value:String);
begin
     GetIniFileName:=Value;
end;

procedure TReposApp.SetTop (Value:Word);
begin
     GetTop:=Value;
end;

procedure TReposApp.SetLeft (Value:Word);
begin
     GetLeft:=Value;
end;

procedure TReposApp.SetHeight (Value:Word);
begin
     GetHeight:=Value;
end;

procedure TReposApp.SetWidth (Value:Word);
begin
     GetWidth:=Value;
end;

procedure TReposApp.SetLeftName (Value:String);
begin
     GetLeftName:=Value;
end;

procedure TReposApp.SetTopName (Value:String);
begin
     GetTopName:=Value;
end;

procedure TReposApp.SetWidthName (Value:String);
begin
     GetWidthName:=Value;
end;

procedure TReposApp.SetHeightName (Value:String);
begin
     GetHeightName:=Value;
end;

procedure Register;
begin
  RegisterComponents('Freeware', [TRePosApp]);
end;

end.
